/*****************************************************************************
 *
 * File: 0E770201.ddl
 *
 *  Copyright (C) Delta-Mobrey	. All Rights Reserved 
 *  Authors:        Jacek Szumigaj & others
 *  Device:         D21/D31 Exd HART 7		        
 *  Communication:  HART 7       
 *  Revision:       1.0                                         
 *  Date:           2020.10.05 		                        
 *****************************************************************************/
 

/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */

// This is a HART 7 device so we will need treat the device type differently for legacy
// hosts (ie, .fms and .fm6)
#if __TOKVER__ >= 800
MANUFACTURER DELTA, DEVICE_TYPE _DPC5_H7r2, DEVICE_REVISION 2, DD_REVISION 1
#else
MANUFACTURER DELTA, DEVICE_TYPE _DPC5_H5r2, DEVICE_REVISION 2, DD_REVISION 1 
#endif

/*****************************************************************************
 * Include Files
 *****************************************************************************
 */

#include "macros.h"
#include "methods.h"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */

/*****************************************************************************
 * Common Tables
 */

IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    HART_DEVICE_TABLES;  // Pulls in all the items for typical HART devices.

    /*
     * Uncomment the following if the device supports trends.  Corresponding
     * commands will also need to be imported from the COMMON_PRACTICE DD.
     */
    //VAR_TREND_TABLES;   // Pulls in all the items for devices that support TRENDS.

    REDEFINITIONS
    {
        VARIABLE device_type
        {
            /* 
             * The type must be redefined if the Device Type is not listed
             * in Common Tables DD
             */
            REDEFINE TYPE ENUMERATED (2)
            {
                // Replace the 0xf9f9 with your Expanded Device Type code and appropriate label
                { 0x0e77,  "D21/D31 Exd HART 7" }
                { 0x0077,  "D21/D31 Exd HART 5" }
            }
        }

        VARIABLE manufacturer_id
        {
            /*
             * The type must be redefined if the Manufacturer code is not listed
             * in the Common Tables DD
             */
            REDEFINE TYPE ENUMERATED (2)
            {
                // Replace the 0x00f9 with your Manufacturer code and appropriate label
                { 0x000e,  "Delta-Mobrey" } 
            }
        }

        VARIABLE private_label_distributor
        {
            /*
             * The type must be redefined if the Private Label code is not listed
             * in the Common Tables DD
             */
            REDEFINE TYPE ENUMERATED (2)
            {
                // Replace the 0x00f9 with your manufactures id and appropriate label
                { 0x000e,  "Delta-Mobrey" } 
            }
        }
    }
}

/*****************************************************************************
 * Universal Commmands
 */

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 7, DD_REVISION 2
{
    // All HART devices must support all Universal Commands
    EVERYTHING;

    REDEFINITIONS
    {
        VARIABLE device_specific_status_0 //change counter H
        {
            REDEFINE LABEL "Change counter - H"; //"wrd_SSMod_H";
            REDEFINE HELP "Higher part of change counter";
            REDEFINE TYPE BIT_ENUMERATED 
            { 
                {0, ""}
            }
        }

        VARIABLE device_specific_status_1 //change counter L
        {
            REDEFINE LABEL "Change counter - L"; //"wrd_SSMod_H";
            REDEFINE HELP "Lower part of change counter";
            REDEFINE TYPE BIT_ENUMERATED 
            { 
                {0, ""}
            }
        }

        VARIABLE device_specific_status_2 //wrd_SSMod_H
        {
            REDEFINE LABEL "Device status 1"; 
            REDEFINE HELP "SSMOD status byte H";
            REDEFINE TYPE BIT_ENUMERATED
            {
        	    { 0x01, "Second or next variable out of limits"},
        		//{ 0x02, ""},
        		//{ 0x04, ""},
        		//{ 0x08, ""},
        		//{ 0x10, ""},
        		{ 0x20, "Analog output saturated"},
        		{ 0x40, "Output current fixed"}
            }                           
        }

        VARIABLE device_specific_status_3 //wrd_SSMod_L
        {
            REDEFINE LABEL "Device status 2"; 
            REDEFINE HELP "SSMOD status byte L";
            REDEFINE TYPE BIT_ENUMERATED
            {
        		{ 0x01, "Security violation"},
        		{ 0x02, "Clock fault"},
        		{ 0x04, "Memory fault"},
        		{ 0x08, "Sensor fault"},
        		{ 0x10, "Barrier communication fault"},
        		{ 0x20, "Internal voltage fault"},
        		{ 0x40, "Current loop regulation fault"},
                { 0x80, "PV out of limits"} 
            }                           
        }

        VARIABLE device_specific_status_14 //AI Block memory status
        {
            REDEFINE LABEL "Analog Input Block Memory Diagnostics Flags";
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "INFO block checksum fault"},
        		{ 0x02, "INFO block recovery"},
        		{ 0x04, "INFO recovery fault"},
        		{ 0x08, "Backup INFO block checksum fault"},
        		{ 0x10, "Backup INFO block recovery"},
        		{ 0x20, "Backup INFO block recovery fault"},
        		{ 0x40, "Flash consistency fault"},
        		{ 0x80, "Flash CRC hot test fault"}    
            }                           
        }

        VARIABLE device_specific_status_15 //PB Block memory status
        {
            REDEFINE LABEL "Phisical Block Memory Diagnostics Flags";
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "INFO block checksum fault"},
        		{ 0x02, "INFO block recovery"},
        		{ 0x04, "INFO recovery fault"},
        		{ 0x08, "Backup INFO block checksum fault"},
        		{ 0x10, "Backup INFO block recovery"},
        		{ 0x20, "Backup INFO block recovery fault"},
        		{ 0x40, "Flash consistency fault"},
        		{ 0x80, "Flash CRC hot test fault"}    
            }                           
        }

        VARIABLE device_specific_status_16 //SB Block memory status
        {
            REDEFINE LABEL "Sensor Block Memory Diagnostics Flags";
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "INFO block checksum fault"},
        		{ 0x02, "INFO block recovery"},
        		{ 0x04, "INFO recovery fault"},
        		{ 0x08, "Backup INFO block checksum fault"},
        		{ 0x10, "Backup INFO block recovery"},
        		{ 0x20, "Backup INFO block recovery fault"},
        		{ 0x40, "Flash consistency fault"},
        		{ 0x80, "Flash CRC hot test fault"}    
            }                           
        }

        VARIABLE device_specific_status_17 //TB Block memory status
        {
            REDEFINE LABEL "Transducer Block Memory Diagnostics Flags"; 
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "INFO block checksum fault"},
        		{ 0x02, "INFO block recovery"},
        		{ 0x04, "INFO recovery fault"},
        		{ 0x08, "Backup INFO block checksum fault"},
        		{ 0x10, "Backup INFO block recovery"},
        		{ 0x20, "Backup INFO block recovery fault"},
        		{ 0x40, "Flash consistency fault"},
        		{ 0x80, "Flash CRC hot test fault"}    
            }                           
        }

        //AIB H - tego bajtu w tej wersji nie ma, ale moze kiedys bedzie...
        //w trybie HART 5 status_19 zawiera rejestr statusowy PB
        /*VARIABLE device_specific_status_18 //AIB H
        {
            REDEFINE LABEL "Analog Input Block Status"; 
            REDEFINE HELP "Analog Input Block status flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                
            }                           
        }*/

        VARIABLE device_specific_status_19 //AIB L
        {
            REDEFINE LABEL "Analog Input Block Diagnostics Status"; 
            REDEFINE HELP "Analog Input Block status flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "AI Current Loop Fault"}
            }                           
        }


        //
        // uwaga:
        // PB H (ale nie zdefiniowane, moze kiedys)
        // w trybie HART 5 znajduje się tutaj SB L
        // 
        /*VARIABLE device_specific_status_20 //PB H (w trybie H5 starszy bajt SB)
        {
            REDEFINE LABEL "Phisical Block Memory Diagnostics Flags"; 
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
        		
            }                           
        }*/

        VARIABLE device_specific_status_21 //PB L (w trybie H5 młodszy bajt SB)
        {
            REDEFINE LABEL "Phisical Block Diagnostics Status"; 
            REDEFINE HELP "Block Memory Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
        		{ 0x01, "LFXT1 fault"},
        		{ 0x02, "AVCC VEREF fault"},
        		{ 0x04, "Local loopback (Master) fault"},
        		{ 0x08, "Remote loopback (Slave) fault"}    
        		{ 0x10, "Barrier data error"}    
        		{ 0x20, "ADC not ready"}    
        		{ 0x40, "MSP temp over"}    
        		{ 0x80, "MSP temp under"}    
            }                           
        }

        /*
        device_specific_status_22 (INFO),   // SB H   - w H5: TB
        // w trybie H5 tego nie ma:                                    
        device_specific_status_23 (INFO),   // SB L
        device_specific_status_24 (INFO)    // TB
        */

        VARIABLE device_specific_status_22 //SB H (w trybie H5: TB)
        {
            REDEFINE LABEL "Sensor Block Diagnostics Status 1"; 
            REDEFINE HELP "Sensor Block Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "Head Temp over"},
                { 0x02, "Head Temp under"},
                { 0x04, "AVDD voltage fault"},
        		{ 0x08, "BUFC4 read error"},
        		{ 0x10, "Rref under spec error"},
        		{ 0x20, "Sensor consecutive temp 10°C exceed"},
                // 0x40
        		{ 0x80, "AD board revision is not valid"}    
            }                           
        }


        VARIABLE device_specific_status_23 //SB L 
        {
            REDEFINE LABEL "Sensor Block Diagnostics Status 2"; 
            REDEFINE HELP "Sensor Block Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
        		{ 0x01, "AVDD status error (NOREF+ERR @AVDD)"},
        		{ 0x02, "Temp status error (NOREF+ERR @TEMP)"},
        		{ 0x04, "AIN1 status error (NOREF+ERR @AIN1)"},
        		{ 0x08, "AIN2 status error (NOREF+ERR @AIN2)"},    
        		{ 0x10, "ADC config error"},    
        		{ 0x20, "ADC didn't respond (timeout)"},    
        		{ 0x40, "ADC Temp over"},    
        		{ 0x80, "ADC Temp under"}    
            }                           
        }

        VARIABLE device_specific_status_24 //TB 
        {
            REDEFINE LABEL "Transducer Block Diagnostics Status"; 
            REDEFINE HELP "Transducer Block Diagnostics Flags";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "PV over range"},
        		{ 0x02, "PV under range"},
        		{ 0x04, "PV high limited"},
        		{ 0x08, "PV low limited"},    
        		{ 0x10, "Access violation"}    
            }                           
        }
        /* 
         * The transaction will need to be redefined to show the correct
         * number of dynamic variables returned in this command 
         * (Command 3) 
         */
        COMMAND read_dynamic_variables_and_pv_current
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status,
                    PV.DAQ.ANALOG_VALUE,
                    PV.DEVICE_VARIABLE.DIGITAL_UNITS, PV.DEVICE_VARIABLE.DIGITAL_VALUE,
                    SV.DEVICE_VARIABLE.DIGITAL_UNITS, SV.DEVICE_VARIABLE.DIGITAL_VALUE
                }
            }
        }

        /* 
         * The transaction will need to be redefined to show the correct
         * number of dynamic variables returned in this command 
         * (Command 8)
         */
        COMMAND read_dynamic_variable_classification
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status,
                    PV.DEVICE_VARIABLE.CLASSIFICATION,
                    SV.DEVICE_VARIABLE.CLASSIFICATION,
                    250,
                    250
                }
            }
        }

        // Remove the command 48 status bytes that are not supported by the device
        // See also command 48 related items in the common practice imports.
        COMMAND read_additional_device_status
        {
            REDEFINE TRANSACTION 0
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0, device_specific_status_1, device_specific_status_2,
                    device_specific_status_3, device_specific_status_4, device_specific_status_5,

                    extended_fld_device_status, 0x00,

                    standardized_status_0, standardized_status_1, analog_channel_saturated1,
                    standardized_status_2, standardized_status_3, analog_channel_fixed1,

                    device_specific_status_14,
                    device_specific_status_15,
                    device_specific_status_16,
                    device_specific_status_17,
                    device_specific_status_18,
                    device_specific_status_19,
                    device_specific_status_20,
                    device_specific_status_21,
                    device_specific_status_22,
                    device_specific_status_23,
                    device_specific_status_24
                }
            }

            REDEFINE TRANSACTION 1
            {
                REQUEST
                {
                    device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
                    device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),

                    extended_fld_device_status (INFO), 0x00,

                    standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
                    standardized_status_2 (INFO), standardized_status_3 (INFO), analog_channel_fixed1 (INFO),

                    device_specific_status_14 (INFO),
                    device_specific_status_15 (INFO),
                    device_specific_status_16 (INFO),
                    device_specific_status_17 (INFO),
                    device_specific_status_18 (INFO),
                    device_specific_status_19 (INFO),
                    device_specific_status_20 (INFO),
                    device_specific_status_21 (INFO),
                    device_specific_status_22 (INFO),
                    device_specific_status_23 (INFO),
                    device_specific_status_24 (INFO)
                }
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
                    device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),

                    extended_fld_device_status (INFO), 0x00,

                    standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
                    standardized_status_2 (INFO), standardized_status_3 (INFO), analog_channel_fixed1 (INFO),

                    device_specific_status_14 (INFO),
                    device_specific_status_15 (INFO),
                    device_specific_status_16 (INFO),
                    device_specific_status_17 (INFO),
                    device_specific_status_18 (INFO),
                    device_specific_status_19 (INFO),
                    device_specific_status_20 (INFO),
                    device_specific_status_21 (INFO),
                    device_specific_status_22 (INFO),
                    device_specific_status_23 (INFO),
                    device_specific_status_24 (INFO)
                }
            }
        }
    }
}

/*****************************************************************************
 * PV, when the primary variable is not mappable we can import the PV
 * standard DD to take care of the dynamic variable array, loop current
 * and ranging functions
 */

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        /*
         * Remove the device variables not used in this DD.
         */
        DELETE COLLECTION tertiary_variable;
        DELETE COLLECTION quaternary_variable;

        ARRAY OF COLLECTION dynamic_variables
        {
            ELEMENTS
            {
                DELETE TERTIARY;
                DELETE QUATERNARY;
            }
        }

        /* 
         * Most devices use the same data item for range units (command 15) and the sensor units.
         * when this is true the following should be added.  if your device uses a different variable
         * for range units you should reference it here 
         */
        COLLECTION OF VARIABLE scaling
        {
            MEMBERS
            {
                ADD RANGE_UNITS, deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
            } 
        }
    }
}

/*****************************************************************************
 * Common Practice Commands
 */

IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 9, DD_REVISION 2
{
    COMMAND write_pv_damping_value;                     // command 34 
    COMMAND write_pv_range_values;                      // Command 35
    COMMAND set_pv_upper_range_value;                   // Command 36
    COMMAND set_pv_lower_range_value;                   // Command 37
    COMMAND enter_exit_fixed_pv_current_mode;           // Command 40
    COMMAND perform_self_test;                          // Command 41
    COMMAND perform_device_reset;                       // Command 42
    COMMAND set_pv_zero;                                // Command 43
    COMMAND write_pv_units;                             // Command 44
    COMMAND trim_pv_current_dac_zero;                   // Command 45
    COMMAND trim_pv_current_dac_gain;                   // Command 46
    COMMAND write_pv_transfer_function;                 // Command 47
    COMMAND read_device_variable_information;           // Command 54
    COMMAND write_number_of_response_preambles;         // Command 59
    COMMAND squawk;                                     // Command 72
    COMMAND write_device_variable;                      // Command 79
    COMMAND read_device_variable_trim_point;            // Command 80
    COMMAND read_device_variable_trim_guidelines;       // Command 81
    COMMAND write_device_variable_trim_point;           // Command 82
    COMMAND reset_device_variable_trim;                 // Command 83

    METHOD applied_rerange;
    METHOD zero_trim;
    METHOD return_to_normal;
    METHOD warning_message;
    METHOD device_self_test;
    METHOD device_master_reset;
    METHOD transmitter_loop_test;
    METHOD leave_fixed_current_mode;
    METHOD transmitter_dac_trim;
    METHOD makeItSquawk;
    METHOD device_variable_trim;
    METHOD trim_warning;
    METHOD device_variable_trim_reset;

    VARIABLE device_variable_code;
    VARIABLE device_variable_trim_code;

    REDEFINITIONS
    {
        VARIABLE device_variable_trim_code
        {
            REDEFINE TYPE INDEX trimDeviceVariables; 
        }

        VARIABLE transfer_function
        {
            REDEFINE HANDLING READ & WRITE;
            REDEFINE TYPE ENUMERATED
            {
                TRANSFER_FUNCTION_CODE (0), // LINEAR   
                TRANSFER_FUNCTION_CODE (1), // SQRT
                TRANSFER_FUNCTION_CODE (4), // SPECIAL
                TRANSFER_FUNCTION_CODE (5), // SQUARE
                { 240, "Manufacturer specific 1" }, // Manufacturer specific function
                { 241, "Manufacturer specific 2" }, // Manufacturer specific function
                { 242, "Manufacturer specific 3" }, // Manufacturer specific function
                { 243, "Manufacturer specific 4" }, // Manufacturer specific function
                { 244, "Manufacturer specific 5" }, // Manufacturer specific function
                { 245, "Manufacturer specific 6" }, // Manufacturer specific function
                { 246, "Manufacturer specific 7" }, // Manufacturer specific function
                { 247, "Manufacturer specific 8" }, // Manufacturer specific function
                { 248, "Manufacturer specific 9" }, // Manufacturer specific function
                { 249, "Manufacturer specific 10" } // Manufacturer specific function
            }
        } 

        VARIABLE write_protect
        {  
            REDEFINE HANDLING READ & WRITE;
            REDEFINE TYPE ENUMERATED
            {
                WRITE_PROTECT_CODE(0),  // NO
                WRITE_PROTECT_CODE(1),  // YES 
                WRITE_PROTECT_CODE(253)  // SPECIAL (MID)
            }
        }
    
    }
}

/*
 * Dynamic Variables Configuration
 */
VARIABLE pressureValue
{
    LABEL [pressure_value];
    HELP [digital_value_pressure_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureUnits
{
    LABEL [pressure_value_unit];
    HELP [digital_units_pressure_help];
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { 0x01,   [InH2O],                [inches_of_water_68_degrees_F_help] },
        { 0x02,   [InHg],                 [inches_of_mercury_0_degrees_C_help] },
        { 0x03,   [FtH2O],                [feet_of_water_68_degrees_F_help] },
        { 0x04,   [mmH2O],                [millimeters_of_water_68_degrees_F_help] },
        { 0x05,   [mmHg],                 [millimeters_of_mercury_0_degrees_C_help] },
        { 0x06,   [psi],                  [pounds_per_square_inch_help] },
        { 0x07,   [bar],                  [bars_help] },
        { 0x08,   [mbar],                 [millibars_help] },
        { 0x09,   [g_SqCm],               [grams_per_square_centimeter_help] },
        { 0x0A,   [kg_SqCm],              [kilograms_per_square_centimeter_help] },
        { 0x0B,   [PA],                   [pascals_help] },
        { 0x0C,   [kPA],                  [kilopascals_help] },
        { 0x0D,   [torr],                 [torr_help] },
        { 0x0E,   [ATM],                  [atmospheres_help] },
        { 0x91,   [in_H2O_60_degrees_F],  [inches_of_water_60_degrees_F_help] },
        { 0xAA,   [cm_H20_4_degrees_C],   [centimeters_of_water_4_degrees_C_help] },
        { 0xAB,   [m_H20_4_degrees_C],    [meters_of_water_4_degrees_C_help] },
        { 0xAC,   [cm_Hg_0_degrees_C],    [centimeters_of_mercury_0_degrees_C_help] },
        { 0xAD,   [lb_SqFt],              [pounds_square_foot_help] },
        { 0xAE,   [hPa],                  [hPa_help] },
        { 0xAF,   [lb_SqIn_abs],          [pounds_square_inch_absolute_help] },
        { 0xB0,   [kg_Sqm],               [kilograms_per_square_meter_help] },
        { 0xB1,   [ft_H20_4_degrees_C],   [feet_of_water_4_degrees_C_help] },
        { 0xB2,   [ft_H2O_60_degrees_F],  [feet_of_water_60_degrees_F_help] },
        { 0xB3,   [m_Hg_0_degrees_C],     [meters_of_mercury_0_degrees_C_help] },
        { 0xED,   [mega_pascals],         [megapascals_help] },
        { 0xEE,   [in_H2O_4_degrees_C],   [inches_of_water_4_degrees_C_help] },
        { 0xEF,   [mm_H2O_4_degrees_C],   [millimeters_of_water_4_degrees_C_help] }
    }
}

VARIABLE pressureFamily
{
    LABEL "Pres Dev fmly";
    HELP [device_family_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the pressure device variable supports the Pressure Family,
         * however, this DD is not complete because there are no Pressure Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(5)      // This is the macro from above macros.h
    }
}

VARIABLE pressureClassification
{
    LABEL "Pres Class";
    HELP [classification_help];
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(65)
    }
}

VARIABLE pressurePDQ
{
    LABEL "Pres PDQ";
    HELP [process_data_quality_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        {0 , process_data_status(0)},
        {1 , process_data_status(1)},
        {2 , process_data_status(2)},
        {3 , process_data_status(3)}

        // PROCESS_DATA_STATUS_CODES      // if preferred, use this macro */         
    }
}

VARIABLE pressureLS
{
    LABEL "Pres LS";
    HELP [limit_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE pressureStatus
{
    LABEL "Pres Fmly stat";
    HELP [family_status_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE pressureUSL
{
    LABEL [pressure_upper_sensor_limit];
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureLSL
{
    LABEL [pressure_lower_sensor_limit];
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureMinimumSpan
{
    LABEL [pressure_minimum_span];
    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureDampingValue
{
    LABEL [pressure_damping_value];
    HELP  [seconds_damping_value_pressure_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ & WRITE;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

#if __TOKVER__ >= 800
VARIABLE pressureUpdatePeriod
{
    LABEL "Pressure Update Period";
    HELP "";
    HANDLING READ;
    TYPE TIME_VALUE;
}

#else

VARIABLE pressureUpdatePeriod_int
{
    LABEL "Pressure Update Period";
    HELP "";
    HANDLING READ;
    CONSTANT_UNIT "s";
    TYPE UNSIGNED_INTEGER(4)
    {
        SCALING_FACTOR 0.00003125;
    }
}
#endif

VARIABLE pressureSerialNumber
{
    LABEL [pressure_sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE pressureLowerTrimPoint
{
    LABEL "Pres Lower trim";
    HELP [lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureUpperTrimPoint
{
    LABEL "Pres Upper trim";
    HELP [upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureTrimSupport
{
    LABEL "Pres Trim support";
    HELP [trim_support_help];
    HANDLING READ;
    TYPE ENUMERATED (1)
    {
        TRIM_POINT_CODE(1),   // Lower Trim Point Supported  
        TRIM_POINT_CODE(2),   // Upper Trim Point Supported
        TRIM_POINT_CODE(3)    // Lower and Upper Trim Point Supported
    }
}

VARIABLE pressureMinimumLTP
{
    LABEL "Pres Min lower trim";
    HELP [minimum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureMaximumLTP
{
    LABEL "Pres Max lower trim";
    HELP [maximum_lower_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureMinimumUTP
{
    LABEL "Pres Min upper trim";
    HELP [minimum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureMaximumUTP
{
    LABEL "Pres Max upper trim";
    HELP [maximum_upper_trim_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureMinimumTrimDiff
{
    LABEL "Pres Min trim diff";
    HELP [minimum_trim_diff_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE pressureSimulated
{
    LABEL "Simulate";
    HELP "";
    CLASS DEVICE & SERVICE;
    HANDLING WRITE;
    TYPE ENUMERATED
    {
        WRITE_DEVICE_VARIABLE_CODE(0),  /* Normal */
        WRITE_DEVICE_VARIABLE_CODE(1)   /* Fix Value */
    }
}

/* 
 * This is the minimum set of members that any device variable collection must have 
 */
COLLECTION OF VARIABLE press
{
    LABEL [pressure];
    HELP [pressure_help];
    MEMBERS
    {   
        // Sensor Correction Information
        DIGITAL_VALUE,              pressureValue,              [blank],                [digital_value_help];
        DIGITAL_UNITS,              pressureUnits,              [units],                [digital_units_help];
        DATA_QUALITY,               pressurePDQ,                [process_data_quality], [process_data_quality_help];
        LIMIT_STATUS,               pressureLS,                 [limit_status],         [limit_status_help];
        DEVICE_FAMILY_STATUS,       pressureStatus,             [family_status],        [family_status_help];

        CLASSIFICATION,             pressureClassification,     [classification],       [classification_help];
        DEVICE_FAMILY,              pressureFamily,             [device_family],        [device_family_help];

        UPPER_SENSOR_LIMIT,         pressureUSL,                [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         pressureLSL,                [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               pressureMinimumSpan,        [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              pressureDampingValue,       [damping_value],        [seconds_damping_value_help];
        SIMULATED,                  pressureSimulated,          "Simulate",             "";

	#if __TOKVER__ >= 800
        UPDATE_TIME_PERIOD,         pressureUpdatePeriod,       "Update Period"; 
        #else
        UPDATE_TIME_PERIOD,         pressureUpdatePeriod_int,   "Update Period"; 
        #endif

        // Device Information
        SENSOR_SERIAL_NUMBER,       pressureSerialNumber,       [sensor_serial_number], [sensor_serial_number_help];

        // Calibration Information
        TRIM_POINT_UNITS,           pressureUnits,              [trim_unit],            [sensor_trim_unit_help];
        LOWER_TRIM_POINT,           pressureLowerTrimPoint,     [lower_trim],           [lower_trim_help];
        UPPER_TRIM_POINT,           pressureUpperTrimPoint,     [upper_trim],           [upper_trim_help];
        TRIM_POINT_SUPPORT,         pressureTrimSupport,        [trim_support],         [trim_support_help];
        MINIMUM_LOWER_TRIM_POINT,   pressureMinimumLTP,         [minimum_lower_trim],   [minimum_lower_trim_help];
        MAXIMUM_LOWER_TRIM_POINT,   pressureMaximumLTP,         [maximum_lower_trim],   [maximum_lower_trim_help];
        MINIMUM_UPPER_TRIM_POINT,   pressureMinimumUTP,         [minimum_upper_trim],   [minimum_upper_trim_help];
        MAXIMUM_UPPER_TRIM_POINT,   pressureMaximumUTP,         [maximum_upper_trim],   [maximum_upper_trim_help];
        MINIMUM_TRIM_DIFFERENTIAL,  pressureMinimumTrimDiff,    [minimum_trim_diff],    [minimum_trim_diff_help];
    }
}

VARIABLE temperatureValue
{
    LABEL [sensor_temperature];
    HELP [sensor_temperature_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT;
}

VARIABLE temperatureUnits
{
    LABEL "Snsr temp unit"
          "|de|Einh Snsr Temp"
          "|fr|Unité Température de sonde."
          "|kt|sennsa- onndo tanni";

    HELP "Sensor Temperature Units- Engineering unit to be displayed with Sensor Temperature."
         "|de|Einheit Sensortemperatur- Temperatureinheit mit der die Sensortemperatur angezeigt wird."
         "|fr|Unité de temperature de sonde - Unité physique pour exprimer la température du module."
         "|kt|sennsa- onndo tanni - sennsa- onndono hyouzini siyousareru tannidesu";
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { 0x20,  [degC],                  [degrees_celsius_help] },
        { 0x21,  [degF],                  [degrees_fahrenheit_help] },
        { 0x22,  [degR],                  [degrees_rankine_help] },
        { 0x23,  [Kelvin],                [degrees_kelvin_help] }
    }
}

VARIABLE temperatureFamily
{
    LABEL [device_family];
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        /*
         * We have declared that the temperature device variable supports the Temperature Family,
         * however, this DD is not complete because there are no Temperature Family commands in it
         */
        DEVICE_VARIABLE_FAMILY_CODE(4)      // This is the macro from above macros.h
    }
}

VARIABLE temperatureClassification
{
    LABEL "Temp Class";
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        DEVICE_VARIABLE_CLASSIFICATION_CODE(0)  // classification is not used here
    }
}

VARIABLE temperaturePDQ
{
    LABEL "Temp PDQ";
    HELP "";
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        PROCESS_DATA_STATUS_CODES
    }
}

VARIABLE temperatureLS
{
    LABEL "Temp LS";
    HELP "";
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE ENUMERATED
    {
        // This is the macro from above macros.h
        LIMIT_STATUS_CODES
    }
}

VARIABLE temperatureStatus
{
    LABEL "Temp Dev Stat";
    HELP "";
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
        { 0x08, device_family_status(0x08), MORE }
    }
}

VARIABLE temperatureUSL
{
    LABEL "Temp USL";
    HELP [upper_sensor_limit_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureLSL
{
    LABEL "Temp LSL";
    HELP [lower_sensor_limit_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureMinimumSpan
{
    LABEL "Temp min span";
    HELP [minimum_span_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureDampingValue
{
    LABEL [temperature_damping_value];
    HELP  [seconds_damping_value_help];
    // You will probably add a write command for this later
    // Usualy command 34 for Write Primary Variable Damping Value
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

#if __TOKVER__ >= 800
VARIABLE temperatureUpdatePeriod
{
    LABEL "Temp Update Period";
    HELP "";
    TYPE TIME_VALUE;
    HANDLING READ;
}

#else

VARIABLE temperatureUpdatePeriod_int
{
    LABEL "Temp Update Period";
    HELP "";
    HANDLING READ;
    CONSTANT_UNIT "s";
    TYPE UNSIGNED_INTEGER(4)
    {
        SCALING_FACTOR 0.00003125;
    }
}
#endif

VARIABLE temperatureSerialNumber
{
    LABEL "Temp snsr s/n";
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

VARIABLE temperatureSimulated
{
    LABEL "Simulate";
    HELP "";
    CLASS DEVICE & SERVICE;
    HANDLING WRITE;
    TYPE ENUMERATED
    {
        WRITE_DEVICE_VARIABLE_CODE(0),  /* Normal */
        WRITE_DEVICE_VARIABLE_CODE(1)   /* Fix Value */
    }
}


/******************************************************************************************/

VARIABLE local_keys_mode_control_codes
{
	LABEL           "Local Operation";
	HELP            "Local Operation";
    CLASS           LOCAL_DISPLAY;
    DEFAULT_VALUE   0;
	TYPE            ENUMERATED
    {
  		{ 0,    "Enabled" },
		{ 1,    "Disabled" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_information_configuration
{
    LABEL               "Meter Information Configuration";
    HELP                [meter_information_configuration_help];
    CLASS               LOCAL_DISPLAY;
    TYPE                ENUMERATED
    {
		{0,     [not_installed]},
		{1,     "Integral LCD" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_display_mode
{
    LABEL               "Meter display mode";
    HELP                "Meter display mode";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
    {
  	    { 0, "Unit On"},
   	    { 1, "Unit Off"}
    }
  HANDLING    READ & WRITE;
}


VARIABLE meter_display_electronics_bias_control
{
    LABEL               "Meter display contrast";
    HELP                "Meter display contrast";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
	{
        {0, "NOT USED"}    
	}
    HANDLING    READ & WRITE;
}


VARIABLE LCD1_display_variable
{
    LABEL               "LCD1 display variable";
    HELP                "LCD1 display variable";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
 		{0,     "Current"},
		{1,     "Percent of Range" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE LCD2_display_variable
{
    LABEL               "LCD2 display variable";
    HELP                "LCD2 display variable";
    CLASS               LOCAL_DISPLAY;
	//DEFAULT_VALUE       0;
    TYPE                ENUMERATED(2)
    {
		{2,     "Pressure" },
		{3,     "User Rerange"},
        {0,     "Pressure, no unit displayed" },
        {1,     "User Rerange, no unit displayed"}
    }
    HANDLING    READ & WRITE;
}

VARIABLE LCD_gap
{
    LABEL               "LCD gap";
    HELP                "LCD gap";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
            {0,     "GAP"}
    }
    HANDLING    READ & WRITE;
}

VARIABLE meter_display_variable_decimal_point
{
    LABEL               "Meter display decimal point";
    HELP                "Meter display decimal point";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       6;
    TYPE                ENUMERATED
    {
        {1,     "[.XXXXX]" },
		{2,     "[X.XXXX]" },
		{3,     "[XX.XXX]" },
		{4,     "[XXX.XX]" },
		{5,     "[XXXX.X]" },
		{6,     "[XXXXX.]" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE    users_unit
{
	LABEL           "Users Unit";
    HELP            "Display Unit - Unit that is displayed on the LCD Display";
	CLASS           DEVICE;
	TYPE            ASCII(7);
    HANDLING READ & WRITE;
}

VARIABLE rearrange_shift
{
	LABEL           "Rearrange Shift";
	HELP            "Rearrange Shift";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}

VARIABLE rearrange_ampl
{
	LABEL           "Rearrange Ampl";
	HELP            "Rearrange Ampl";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}

VARIABLE startpoint_rad                                 
{
	LABEL           "Startpoint rad";
    HELP            "Determines the transition from linear resp. 4mA-constant to square root (Transfer Function).";  
    CLASS           INPUT;
    TYPE            FLOAT
	{
	    DISPLAY_FORMAT "5.2f";
    }
    
    CONSTANT_UNIT    [Percent];
	HANDLING READ & WRITE;
}

/********************Device specific commands - LCD *************************************************/
COMMAND write_control_modes
{
	NUMBER 132;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			local_keys_mode_control_codes, 	/* U8,  0 = enabled. 1 = disabled */
			meter_information_configuration, 	/* U8, 0 = not_installed, 1 = integral_LCD */
			meter_display_mode, 			/* U8, 0=unit_on, 1=unit_off */
			meter_display_electronics_bias_control,	/* U8, not used */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>,  
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
							/*{BIT1,BIT0=00,     [LCD1 › current]},
							{BIT1,BIT0=01,     [LCD1 › percent_of_range]},

							{BIT3,BIT2=00,     [LCD2 › pressure]},
							{BIT3,BIT2=01,     [LCD2 › user_rerange]},*/

			meter_display_variable_decimal_point	/* U8
                            {1,     	[.XXXXX]},
							{2,     	[X.XXXX]},
							{3,     	[XX.XXX]},
							{4,     	[XXX.XX]},
							{5,     	[XXXX.X]},
							{6,     	[XXXXX.]}
							*/
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes,  	/* U8 */
			meter_information_configuration,	/* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point /* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		2,  DATA_ENTRY_ERROR,           [invalid_selection];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,				    [in_write_protect_mode];
	}
}


COMMAND read_control_modes
{
	NUMBER 133;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes, 	/* U8 */
			meter_information_configuration,   /* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable,  	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point	/* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

COMMAND write_users_unit_name_and_rearrange_coefficients
{
	NUMBER 244;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			users_unit,     			/* string w formacie ASCII(7) */
			rearrange_shift,			/* IEE754 float, jest to przeskalowanie LRV wyświetlane na LCD w trybie user_rearrange.*/
			rearrange_ampl  			/* IEE754 float, jest to przeskalowanie URV wyświetlane na LCD w trybie user_rearrange. */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,        			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
		5,  MISC_ERROR,                 			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 			[in_write_protect_mode];   
	}
}

COMMAND read_users_unit_name_and_rerange_coefficients
{
	NUMBER 245;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{       

		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,         			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

/**************** read/write start point rad  *******************************/
COMMAND write_startpoint_rad
{
	NUMBER 242;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			startpoint_rad  			/* IEE754 float, wartość w % zakresu */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			startpoint_rad          			/* IEE754 float, wartość w % zakresu */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
		5,  MISC_ERROR,                 			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 			[in_write_protect_mode];   
	}
}

COMMAND read_startpoint_rad
{
    NUMBER 243;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			startpoint_rad          			/* IEE754 float, wartość w % zakresu */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}

/********************** Konfiguracja wyjścia prądowego - alarmy ***********************************************/
VARIABLE aifb_Byte0        /* U8 */
{
    LABEL               "aifb_Byte0";
    HELP                "aifb_Byte0";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE aifb_Byte1        /* U8 */
{
    LABEL               "aifb_Byte1";
    HELP                "aifb_Byte1";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE filtration        /* U8 */
{
    LABEL               "Processing time";
    HELP                "Shorter processing time mean poorer accuracy";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    CONSTANT_UNIT       "[ms]";
    TYPE ENUMERATED
    {
        {3,  " 16"},
        {4,  " 32"},
        {5,  " 40"},
        {6,  " 48"},
        {7,  " 60"},
        {8,  "101"},
        {9,  "120"},
        {10, "120"},
        {11, "160"},
        {12, "200"},
        {13, "240"},
        {14, "320"},
        {15, "480"}
    }
}

VARIABLE DAC_errors
{
    LABEL               "DAC processing block errors";
    HELP                "Błędy bloku przetwarzania DAC";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE ADC_errors
{
    LABEL               "ADC processing block errors";
    HELP                "Błędy bloku przetwarzania ADC";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE memory_errors
{
    LABEL               "RAM, FLASH, EEPROM errors";
    HELP                "Błędy pamięci RAM, FLASH, EEPROM";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE oscillator_errors
{
    LABEL               "CPU oscillator errors";
    HELP                "Błedy oscylatora CPU";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE math_oper_errors
{
    LABEL               "Mathematical operation errors";
    HELP                "Błedy operacji matematycznych";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE range_exceeding_error
{
    LABEL               "Exceeding the ranges of PV, SV, TV, FV";
    HELP                "Przekroczenia zakresów PV, SV, TV, FV";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}




VARIABLE current_alarm_mode
{
    LABEL               "Current Alarm";
    HELP                "Current Alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "HIGH (22 mA)" },       //Alarm Current
		{0x01,     "LOW  (3,6 mA)" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE current_range_mode
{
    LABEL               "Current Range Mode";
    HELP                "Current Range Mode";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "NORMAL (3,9 – 20,5 mA)" }, //Current Range Mode 
		{0x01,     "NAMUR  (3,8 – 20,5 mA)" }
    }
    HANDLING    READ & WRITE;
}

COMMAND write_analog_input_function_block_configuration
{
	NUMBER 141;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
            aifb_Byte0,			/* U8 */
		    aifb_Byte1,			/* U8 */
		    filtration,			/* U8 */

            current_range_mode  <0x80>,
            current_alarm_mode  <0x40>,

            range_exceeding_error <0x20>,   // Przekroczenia zakresów PV, SV, TV, FV
            math_oper_errors    <0x10>,     // Błędy operacji matematycznych
            oscillator_errors   <0x08>,     // Błedy oscylatora CPU
            memory_errors       <0x04>,     // Błędy pamięci RAM, FLASH, EEPROM
            ADC_errors          <0x02>,     // Błędy bloku przetwarzania ADC
            DAC_errors          <0x01>      // Błędy bloku przetwarzania DAC
		}

		REPLY
		{
			response_code,device_status, 	/* U8 */
            aifb_Byte0,			/* U8 */
		    aifb_Byte1,			/* U8 */
		    filtration,			/* U8 */

            current_range_mode  <0x80>,
            current_alarm_mode  <0x40>,

            range_exceeding_error <0x20>,   // Przekroczenia zakresów PV, SV, TV, FV
            math_oper_errors    <0x10>,     // Błędy operacji matematycznych
            oscillator_errors   <0x08>,     // Błedy oscylatora CPU
            memory_errors       <0x04>,     // Błędy pamięci RAM, FLASH, EEPROM
            ADC_errors          <0x02>,     // Błędy bloku przetwarzania ADC
            DAC_errors          <0x01>      // Błędy bloku przetwarzania DAC
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 [in_write_protect_mode];   
	}
}

COMMAND read_analog_input_function_block_configuration
{
	NUMBER 142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{       
		}
		REPLY
		{
			response_code, device_status, 	/* U8 */
			aifb_Byte0,			/* U8 */
		    aifb_Byte1,			/* U8 */
		    filtration,			/* U8 */

            current_range_mode  <0x80>,
            current_alarm_mode  <0x40>,

            range_exceeding_error <0x20>,   // Przekroczenia zakresów PV, SV, TV, FV
            math_oper_errors    <0x10>,     // Błędy operacji matematycznych
            oscillator_errors   <0x08>,     // Błedy oscylatora CPU
            memory_errors       <0x04>,     // Błędy pamięci RAM, FLASH, EEPROM
            ADC_errors          <0x02>,     // Błędy bloku przetwarzania ADC
            DAC_errors          <0x01>      // Błędy bloku przetwarzania DAC
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
	}
}


/************* Soft/Hard revisions ***************************************************/

VARIABLE cpu_hardware_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "CPU hardware major revision";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_hardware_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "CPU hardware minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "CPU software major rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "CPU software minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE master_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "Master software major revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE master_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "Master software minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE slave_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "Slave software major revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE slave_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "Slave software minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE adc_hardware_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "ADC hardware major rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE adc_hardware_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "ADC hardware minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE hart_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "HART software major rev.";
    HANDLING READ;
    TYPE INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE hart_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "HART software minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d"; 
    }
}

COMMAND read_revisions_code
{
    NUMBER 230;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			cpu_hardware_major_revision,    	/* U8 */
			cpu_hardware_minor_revision,        /* U8 */
			cpu_software_major_revision,       /* U8 */
			cpu_software_minor_revision,       /* U8 */
			master_software_major_revision,     /* U8 */
			master_software_minor_revision,     /* U8 */
			slave_software_major_revision,      /* U8 */
			slave_software_minor_revision,      /* U8 */
			adc_hardware_major_revision,        /* U8 */
			adc_hardware_minor_revision,        /* U8 */
			hart_software_major_revision,       /* U8 */
			hart_software_minor_revision        /* U8 */
         }
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}

/**********Return to factory settings *****************************************/

VARIABLE kind_of_trim
{
	LABEL           "Kind of trim";
    HELP            "User calibrations (sensor calibrations) are replaced by the original factory calibrations.";   
    CLASS           INPUT;
    HANDLING        WRITE; 
    TYPE            ENUMERATED
	{
		{ 0,  "zero trim" },
		{ 1,  "sensor trim" },
		{ 2,  "analog output trim" }
	}
}

METHOD  reset_factory_trim_method
{
    LABEL "Reset to factory trim";
    HELP  "Trim";
    DEFINITION 
    {  
        GET_DEV_VAR_VALUE( "Select trim type", kind_of_trim);
        ACKNOWLEDGE("Press OK to Factory Trim");
        send_command(138);       
    }
}

COMMAND reset_factory_trim
{
	NUMBER 138;             
    
	OPERATION WRITE;

	TRANSACTION
	{
		REQUEST
		{
		kind_of_trim			/* U8,
                                    0 = undo zero trim,
                                    1 = sensor trim recall to factory settings,
                                    2 = analog output trim recall to factory settings 
                                */
		}
		REPLY
		{
		response_code, device_status,		/* U8 */
		kind_of_trim			            /* U8 */
		}
	}
    RESPONSE_CODES
	{
		0,  SUCCESS,                    		[no_command_specific_errors];
		2,  DATA_ENTRY_ERROR,           	    [invalid_selection];
		5,  MISC_ERROR,                 		[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 		[in_write_protect_mode];
	}
}

/*******************************************************************************;
;		sub_CMD_247	SET WRITE PROTECT CODE	(5 bajtów danych)                   ;
;*******************************************************************************;
;                   byte 0-3 - customer security code                           ;
;                   byte 4 - write protect code                                 ;
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Po wpisaniu odpowiedniego kodu ustawiany jest write protect code ;
;------------------------------------------------------------------------------*/
 
COMMAND CMD_247
{
    NUMBER 247;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           protect_code, write_protect 
        }
        REPLY
        {
            response_code, device_status, protect_code, write_protect 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      2,  DATA_ENTRY_ERROR, [invalid_selection];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}  

VARIABLE protect_code
{
    LABEL "Customer code";
    HELP  "Customer code";
    CLASS DEVICE;
    HANDLING WRITE;
    DEFAULT_VALUE 0;
    TYPE INTEGER (4);
    /*POST_EDIT_ACTIONS
    {
        set_protect
    } */
}                                                           



METHOD toggle_write_protect
{
    LABEL "Set Write Protect";
    HELP  "";
    DEFINITION 
    {
     assign_int(protect_code,0000);
     GET_DEV_VAR_VALUE( "Type Protect Code", protect_code);
     GET_DEV_VAR_VALUE( "Set Write Protect", write_protect);
     send_command(247);
     //assign_int(protect_code,0000);
    }
}

/********************************************************************************
;		sub_CMD_246	 CHANGE CUSTOMER SECURITY CODE		(8 bajtów danych)
;********************************************************************************
;                   byte 0-3 - old customer security code                       
;                   byte 3-7 - new customer security code
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Umożliwia zmianę kodu zabezpieczającego                          ;
;------------------------------------------------------------------------------*/

COMMAND CMD_246
{
    NUMBER 246;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           old_customer_code, new_customer_code
        }
        REPLY
        {
            response_code, device_status, old_customer_code, new_customer_code 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}  


METHOD change_protect_code
{
    LABEL "Change Protect Code";
    HELP  "";
    DEFINITION 
    {
     assign_int(old_customer_code,0000);
     assign_int(new_customer_code,0000);
     GET_DEV_VAR_VALUE( "Type Old Customer Code", old_customer_code);
     GET_DEV_VAR_VALUE( "Type new Customer Code", new_customer_code);
     send_command(246);
     //assign_int(old_customer_code,0000);
     //assign_int(new_customer_code,0000);
    }
}

VARIABLE old_customer_code
{
    LABEL "Old customer security code";
    HELP  "Old customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;
}

VARIABLE new_customer_code
{
    LABEL "New customer security code";
    HELP  "New customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;
}

/********************* HART 5/7 Switch *************************************************************************/

COMMAND CMD_134
{
    NUMBER 134;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           hart_mode
        }
        REPLY
        {
            response_code, device_status, hart_mode 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}  

VARIABLE hart_mode
{
    LABEL "Hart mode";
    HELP  "HART 7 or HART 5 working mode selector";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE ENUMERATED
    {
        {7, "HART 7"},
        {5, "HART 5"}
    }
    DEFAULT_VALUE  7;
}

METHOD change_hart_mode
{
    LABEL "Change HART protocol mode";
    HELP  "";
    DEFINITION 
    {
        GET_DEV_VAR_VALUE( "Select HART protocol", hart_mode);
        send_command(134);
        ACKNOWLEDGE("Restart identification");
    }
}
/**********************************************************************************************/

COLLECTION OF VARIABLE temperature
{
    LABEL [temperature];
    HELP "Secondary Variable - Temperature Compensation";
    MEMBERS
    {
        // Sensor Correction Information
        DIGITAL_VALUE,              temperatureValue,           [blank],                [digital_value_help];
        DIGITAL_UNITS,              temperatureUnits,           [units],                [digital_units_help];
        DATA_QUALITY,               temperaturePDQ,             [process_data_quality], [process_data_quality_help];  
        LIMIT_STATUS,               temperatureLS,              [limit_status],         [limit_status_help];  
        DEVICE_FAMILY_STATUS,       temperatureStatus,          [family_status],        [family_status_help]; 

        CLASSIFICATION,             temperatureClassification,  [classification],       [classification_help];
        DEVICE_FAMILY,              temperatureFamily,          [device_family],        [device_family_help]; 

        UPPER_SENSOR_LIMIT,         temperatureUSL,             [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         temperatureLSL,             [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               temperatureMinimumSpan,     [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              temperatureDampingValue,    [damping_value],        [seconds_damping_value_help];
        SIMULATED,                  temperatureSimulated,       "Simulate",             "";

        #if __TOKVER__ >= 800
        UPDATE_TIME_PERIOD,         temperatureUpdatePeriod,    "Update Period";        
        #else
        UPDATE_TIME_PERIOD,         temperatureUpdatePeriod_int,"Update Period"; 
        #endif

        // Device Information
        SENSOR_SERIAL_NUMBER,       temperatureSerialNumber,    [sensor_serial_number], [sensor_serial_number_help];
     }
}

ARRAY OF COLLECTION deviceVariables 
{
    ELEMENTS
    {
        0, press,       "Pressure";
        1, temperature, "Temperature";
    }
}

ARRAY OF COLLECTION trimDeviceVariables 
{
    ELEMENTS
    {
        0, press, [pv];
    }
}

/*
 * Relationships
 */

UNIT pressureUnitsRelation
{
    pressureUnits:
        pressureValue,
        pressureUSL,
        pressureLSL,
        pressureMinimumSpan,
        pressureLowerTrimPoint,
        pressureUpperTrimPoint,
        pressureMinimumLTP,
        pressureMaximumLTP,
        pressureMinimumUTP,
        pressureMaximumUTP,
        pressureMinimumTrimDiff
}

UNIT temperatureUnitRelation
{
    temperatureUnits :
        temperatureValue
        temperatureUSL,
        temperatureLSL,
        temperatureMinimumSpan
}

/***************************************************************************
 * below is list of menu declaritions
 * they where take directly from menu.ddl an interoperable file
 * this is a recommended display format derived by the HART communicator
 * developers in conjunction with slave developers and end users.
 */

MENU root_menu
{
    LABEL [bus_devices];
    ITEMS
    {
        device_setup,                                               // menu
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
        SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),

        PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),
        PV.RANGING.LOWER_RANGE_VALUE (DISPLAY_VALUE, READ_ONLY),
        PV.RANGING.UPPER_RANGE_VALUE (DISPLAY_VALUE, READ_ONLY)
    }
}

MENU device_setup
{
    LABEL [device_setup];
    ITEMS
    {
        process_variables,                                          // menu
        diag_service,                                               // menu
        basic_setup,                                                // menu
        detailed_setup,                                             // menu
        review (REVIEW)                                             // menu
    }
}

MENU process_variables
{
    LABEL [process_variables];
    ITEMS
    {
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
        PV.RANGING.PERCENT_RANGE (DISPLAY_VALUE),
        PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE),
        SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE)
    }
}

MENU diag_service
{
    LABEL [diagnostics_and_service];
    ITEMS
    {
        test_device,                                                // menu
        calibration                                                 // menu
    }
}

MENU test_device
{
    LABEL [test_device];
    ITEMS
    {
        status_display,                                             // menu
        device_self_test,                                           // method
        device_master_reset,                                        // method
        makeItSquawk                                                // method
    }
}

MENU calibration
{
    LABEL [calibration];
    ITEMS
    {
        menu_rerange,                                               // menu
        analog_output,                                              // menu
        menu_sensor_trim,                                            // menu
        reset_factory_trim_method
    }
}

/*MENU return_to_factory_settings
{
    LABEL "Return to Factory Settings";
    ITEMS 
    {  
        //kind_of_trim,
        reset_factory_trim_method
        //reset_device         
    } 
}*/

MENU menu_rerange
{
    LABEL "Re-range";
    ITEMS
    {
        rerange,                                                    // edit display
        applied_rerange                                             // method
    }
}

MENU menu_sensor_trim
{
    LABEL [sensor_trim];
    ITEMS
    {
        zero_trim,                                                  // method
        device_variable_trim,                                       // method
        device_variable_trim_reset,                                 // method
        menu_sensor_trim_points (REVIEW)                            // menu
    }
}

MENU menu_sensor_trim_points
{
    LABEL "Sensor trim points"
          "|fr|Points d'etalonnage du capteur"
          "|de|Abgl.punkte Sensor"
          "|kt|sennsa-torimu poinnto";
    ITEMS
    {
        deviceVariables[0].LOWER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].UPPER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].TRIM_POINT_SUPPORT (DISPLAY_VALUE),
        deviceVariables[0].TRIM_POINT_UNITS (DISPLAY_VALUE),
        deviceVariables[0].MINIMUM_LOWER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].MAXIMUM_LOWER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].MINIMUM_UPPER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].MAXIMUM_UPPER_TRIM_POINT (DISPLAY_VALUE),
        deviceVariables[0].MINIMUM_TRIM_DIFFERENTIAL (DISPLAY_VALUE)
    }
}

MENU status_display
{
    LABEL [status];
    ITEMS
    {
        //device_specific_status_0 (DISPLAY_VALUE), // change counter H
        //device_specific_status_1 (DISPLAY_VALUE), // change counter L
        device_specific_status_2 (DISPLAY_VALUE), // SSmodH
        device_specific_status_3 (DISPLAY_VALUE), // SSmodL
        //device_specific_status_4 (DISPLAY_VALUE),
        //device_specific_status_5 (DISPLAY_VALUE),
        extended_fld_device_status (DISPLAY_VALUE),
        operatingMode (DISPLAY_VALUE),

        status_AIB,
        status_PB,
        status_SB,
        status_TB
    }
}

MENU status_AIB
{
    LABEL "Analog Input Block";
    ITEMS
    {
        device_specific_status_14 (DISPLAY_VALUE),   //AI MB
        //device_specific_status_18 (DISPLAY_VALUE),   // AIB H
        device_specific_status_19 (DISPLAY_VALUE)    // AIB L - w H5: PB
    }
}

MENU status_PB
{
    LABEL "Phisical Block";
    ITEMS
    {
        device_specific_status_15 (DISPLAY_VALUE),   //PB MB
        //device_specific_status_20 (DISPLAY_VALUE),   // PB H  - w H5: SB
        device_specific_status_21 (DISPLAY_VALUE)    // PB L  - w H5: SB
    }
}


MENU status_SB
{
    LABEL "Sensor Block";
    ITEMS
    {
        device_specific_status_16 (DISPLAY_VALUE),   //SB MB
        device_specific_status_22 (DISPLAY_VALUE),   // SB H  - w H5: TB
        device_specific_status_23 (DISPLAY_VALUE)    // SB L - w H5 nie uzywane
    }
}


MENU status_TB
{
    LABEL "Transducer Block";
    ITEMS
    {
        device_specific_status_17 (DISPLAY_VALUE),   //TB MB
        device_specific_status_24 (DISPLAY_VALUE)    // TB   - w H5 nie uzywane
    }
}

MENU basic_setup
{
    LABEL [basic_setup];
    ITEMS
    {
        tag (DISPLAY_VALUE),
        longTag (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DIGITAL_UNITS,
        PV.RANGING.TRANSFER_FUNCTION,
        PV.DEVICE_VARIABLE.DAMPING_VALUE,
        startpoint_rad (DISPLAY_VALUE),
        rerange,                                                    // edit display
        device_info,                                                 // menu
        menu_lcd
    }
}

MENU detailed_setup
{
    LABEL [detailed_setup];
    ITEMS
    {
        measuring_elements,                                         // menu
        signal_conditioning,                                        // menu
        output_conditioning,                                        // 
        menu_set_write_protection,
        menu_lcd,
        device_info                                                 // menu
    }
}

MENU device_info
{
    LABEL [device_information];
    ITEMS
    {
        private_label_distributor (DISPLAY_VALUE),
        device_type (DISPLAY_VALUE),
        device_id (DISPLAY_VALUE),
        config_change_counter (DISPLAY_VALUE),
        tag (DISPLAY_VALUE),
        longTag (DISPLAY_VALUE),
        date (DISPLAY_VALUE),
        write_protect (DISPLAY_VALUE),
        descriptor (DISPLAY_VALUE),
        message (DISPLAY_VALUE),
        final_assembly_number (DISPLAY_VALUE),
        device_revisions                                            // menu
    }
}

MENU device_revisions
{
    LABEL [revision_numbers];
    ITEMS
    {
        universal_revision (DISPLAY_VALUE),
        transmitter_revision (DISPLAY_VALUE),
        software_revision (DISPLAY_VALUE),
        hardware_revision (DISPLAY_VALUE)
        menu_all_revisions
    }
}

MENU measuring_elements
{
    LABEL [sensors];
    ITEMS
    {
        menu_pres_sensor,                                           // menu
        menu_temp_sensor,                                           // menu
        max_num_device_variables (DISPLAY_VALUE)
    }
}

MENU menu_pres_sensor
{
    LABEL [pressure_sensor];
    ITEMS
    {
        deviceVariables[0].DIGITAL_VALUE (DISPLAY_VALUE),
        deviceVariables[0].DIGITAL_UNITS (DISPLAY_VALUE),
        menu_sensor_trim,                                           // menu
        menu_sensor_info (REVIEW)                                   // menu
    }
}

MENU menu_temp_sensor
{
    LABEL "Temperature sensor";
    ITEMS
    {
        deviceVariables[1].DIGITAL_VALUE (DISPLAY_VALUE),
        deviceVariables[1].DIGITAL_UNITS (DISPLAY_VALUE),
        menu_sensor2_info (REVIEW)                                  // menu
    }
}

MENU menu_sensor_info
{
    LABEL [sensor_info];
    ITEMS
    {
        deviceVariables[0].DEVICE_FAMILY (DISPLAY_VALUE),
        deviceVariables[0].CLASSIFICATION (DISPLAY_VALUE),
        deviceVariables[0].DATA_QUALITY (DISPLAY_VALUE),
        deviceVariables[0].LIMIT_STATUS (DISPLAY_VALUE),
        deviceVariables[0].DEVICE_FAMILY_STATUS (DISPLAY_VALUE),
        deviceVariables[0].LOWER_SENSOR_LIMIT (DISPLAY_VALUE),
        deviceVariables[0].UPPER_SENSOR_LIMIT (DISPLAY_VALUE),
        deviceVariables[0].MINIMUM_SPAN (DISPLAY_VALUE),
        deviceVariables[0].DAMPING_VALUE (DISPLAY_VALUE),
        deviceVariables[0].SENSOR_SERIAL_NUMBER (DISPLAY_VALUE)
    }
}

MENU menu_sensor2_info
{
    LABEL [sensor_info];
    ITEMS
    {
        deviceVariables[1].DEVICE_FAMILY (DISPLAY_VALUE),
        deviceVariables[1].CLASSIFICATION (DISPLAY_VALUE),
        deviceVariables[1].DATA_QUALITY (DISPLAY_VALUE),
        deviceVariables[1].LIMIT_STATUS (DISPLAY_VALUE),
        deviceVariables[1].DEVICE_FAMILY_STATUS (DISPLAY_VALUE),
        deviceVariables[1].LOWER_SENSOR_LIMIT (DISPLAY_VALUE),
        deviceVariables[1].UPPER_SENSOR_LIMIT (DISPLAY_VALUE),
        //deviceVariables[1].MINIMUM_SPAN (DISPLAY_VALUE),
        //deviceVariables[1].DAMPING_VALUE (DISPLAY_VALUE),
        deviceVariables[1].SENSOR_SERIAL_NUMBER (DISPLAY_VALUE)
    }
}

MENU signal_conditioning
{
    LABEL [signal_condition];
    ITEMS
    {
        PV.RANGING.LOWER_RANGE_VALUE (DISPLAY_VALUE),
        PV.RANGING.UPPER_RANGE_VALUE (DISPLAY_VALUE),
        PV.RANGING.PERCENT_RANGE (DISPLAY_VALUE),
        PV.RANGING.TRANSFER_FUNCTION (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DAMPING_VALUE (DISPLAY_VALUE)
    }
}

MENU output_conditioning
{
    LABEL [output_condition];
    ITEMS
    {
        analog_output,                                              // Menu
        hart_output                                                 // Menu
    }
}

MENU analog_output
{
    LABEL [analog_output];
    ITEMS
    {
        PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE,READ_ONLY),
        PV.DAQ.ALARM_CODE (DISPLAY_VALUE),
        PV.DAQ.ANALOG_CHANNEL_FLAGS (DISPLAY_VALUE),
        loop_current_mode  (DISPLAY_VALUE),
        transmitter_loop_test,                                      // method
        transmitter_dac_trim,                                       // method
        current_range_mode (DISPLAY_VALUE),
        current_alarm_mode (DISPLAY_VALUE),
        filtration (DISPLAY_VALUE),
        current_alarm_config_menu
    }
}

MENU current_alarm_config_menu
{
    LABEL "Current alarm configuration";
    ITEMS
    {
        DAC_errors (DISPLAY_VALUE),
        ADC_errors (DISPLAY_VALUE),
        memory_errors (DISPLAY_VALUE),
        oscillator_errors(DISPLAY_VALUE),
        math_oper_errors (DISPLAY_VALUE),
        range_exceeding_error (DISPLAY_VALUE)
    }
}

MENU hart_output
{
    LABEL [HART_output];
    ITEMS
    {
        polling_address (DISPLAY_VALUE),
        request_preambles (DISPLAY_VALUE),
        response_preambles (DISPLAY_VALUE),
        change_hart_mode
    }
}

MENU review
{
    LABEL [review];
    ITEMS
    {
        device_type (DISPLAY_VALUE, READ_ONLY),
        private_label_distributor (DISPLAY_VALUE, READ_ONLY),
        write_protect (DISPLAY_VALUE, READ_ONLY),
        device_id (DISPLAY_VALUE, READ_ONLY),
        config_change_counter (DISPLAY_VALUE, READ_ONLY),
        max_num_device_variables  (DISPLAY_VALUE, READ_ONLY),
        tag (DISPLAY_VALUE, READ_ONLY),
        longTag (DISPLAY_VALUE, READ_ONLY),
        descriptor (DISPLAY_VALUE, READ_ONLY),
        message (DISPLAY_VALUE, READ_ONLY),
        date (DISPLAY_VALUE, READ_ONLY),
        final_assembly_number (DISPLAY_VALUE),
        universal_revision (DISPLAY_VALUE, READ_ONLY),
        transmitter_revision (DISPLAY_VALUE, READ_ONLY),
        software_revision (DISPLAY_VALUE, READ_ONLY),
        polling_address (DISPLAY_VALUE, READ_ONLY),
        loop_current_mode (DISPLAY_VALUE, READ_ONLY),
        request_preambles (DISPLAY_VALUE, READ_ONLY),
        response_preambles (DISPLAY_VALUE, READ_ONLY)
    }
}

MENU menu_lcd
{
    LABEL "LCD";
    ITEMS 
    {  
        menu_local_LCD,
        menu_user_rarange
    }
}

MENU menu_local_LCD
{
    LABEL "LCD configuration";
    ITEMS 
    {  
        local_keys_mode_control_codes (DISPLAY_VALUE),
        meter_information_configuration (DISPLAY_VALUE),       
        LCD2_display_variable (DISPLAY_VALUE),
        LCD1_display_variable (DISPLAY_VALUE),
        meter_display_variable_decimal_point (DISPLAY_VALUE)//,
        //[blank]

    }
}

MENU menu_user_rarange
{
    LABEL "User Rerange";
    HELP "User Rerange";
    ITEMS 
    {  
    //[blank],
    users_unit (DISPLAY_VALUE)//,
    rearrange_shift (DISPLAY_VALUE),
    rearrange_ampl (DISPLAY_VALUE)//,
    //[blank]
    }
}

MENU menu_all_revisions
{
    LABEL "Revision details";
    ITEMS
    {
        ADC_revision,
        CPU_hardware_revision,
        CPU_software_revision
    }
}
        
MENU ADC_revision
{
    LABEL "ADC hardware revision";
    ITEMS 
    {  
        adc_hardware_major_revision (DISPLAY_VALUE),
        adc_hardware_minor_revision (DISPLAY_VALUE)
    }
}

MENU CPU_hardware_revision
{
    LABEL "CPU hardware revision";
    ITEMS 
    {  
        cpu_hardware_major_revision (DISPLAY_VALUE), //cpu_hardware_rev, 
        cpu_hardware_minor_revision (DISPLAY_VALUE)
    }
}

MENU CPU_software_revision
{
    LABEL "CPU software revision";
    ITEMS 
    {  
        cpu_software_major_revision (DISPLAY_VALUE), //cpu_software_rev,
        cpu_software_minor_revision (DISPLAY_VALUE)        
    }
}

MENU Master_software_revision
{
    LABEL "Master software revision";
    ITEMS 
    {  
        master_software_major_revision (DISPLAY_VALUE), //master_software_rev,
        master_software_minor_revision (DISPLAY_VALUE)        
    }
}

MENU Slave_software_revision
{
    LABEL "Slave software revision";
    ITEMS 
    {  
        slave_software_major_revision (DISPLAY_VALUE), //slave_software_rev,
        slave_software_minor_revision (DISPLAY_VALUE)               
    }
}

MENU Hart_software_revision
{
    LABEL "Hart software revision";
    ITEMS 
    {  
        hart_software_major_revision (DISPLAY_VALUE),
        hart_software_minor_revision (DISPLAY_VALUE)                  
    }
}

MENU menu_set_write_protection
{
    LABEL "Write protection";
    ITEMS 
    {  
       write_protect (DISPLAY_VALUE, READ_ONLY),
       toggle_write_protect,
       change_protect_code
    }
} 

EDIT_DISPLAY rerange
{
    LABEL [range_values];
    EDIT_ITEMS
    { 
        scaling_wao, 
        PV.DEVICE_VARIABLE.DIGITAL_UNITS
    }
    DISPLAY_ITEMS
    {
        PV.DEVICE_VARIABLE.LOWER_SENSOR_LIMIT,
        PV.DEVICE_VARIABLE.UPPER_SENSOR_LIMIT
    }
}


